<?php

namespace Church\Church\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Church\Church\Interfaces\PermisosModuleRepositoryInterface;
use Church\Church\Repositories\Presenter\PermisosModuleItemTransformer;

/**
 * Pubic API controller class.
 */
class PermisosModulePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Church\PermisosModule\Interfaces\PermisosModuleRepositoryInterface $permisos_module
     *
     * @return type
     */
    public function __construct(PermisosModuleRepositoryInterface $permisos_module)
    {
        $this->repository = $permisos_module;
        parent::__construct();
    }

    /**
     * Show permisos_module's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $permisos_modules = $this->repository
            ->setPresenter('\\Church\\Church\\Repositories\\Presenter\\PermisosModuleListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $permisos_modules['code'] = 2000;
        return response()->json($permisos_modules)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show permisos_module.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $permisos_module = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($permisos_module)) {
            $permisos_module         = $this->itemPresenter($module, new PermisosModuleItemTransformer);
            $permisos_module['code'] = 2001;
            return response()->json($permisos_module)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
