<?php

namespace Church\Church\Http\Controllers;
use Litepie\Church\Http\Requests\PermisosModuleRequest;
use Litepie\Church\Models\PermisosModule;

trait PermisosModuleWorkflow {
	
    /**
     * Workflow controller function for permisos_module.
     *
     * @param Model   $permisos_module
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PermisosModuleRequest $request, PermisosModule $permisos_module, $step)
    {

        try {

            $permisos_module->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('church::permisos_module.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/permisos_module/permisos_module/' . $permisos_module->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/permisos_module/permisos_module/' . $permisos_module->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for permisos_module.
     *
     * @param Model   $permisos_module
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(PermisosModule $permisos_module, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $permisos_module->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('church::permisos_module.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('church::admin.permisos_module.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('church::admin.permisos_module.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('church::admin.permisos_module.message', $data)->render();

        }

    }
}