<?php

namespace Church\Church\Policies;

use App\User;
use Church\Church\Models\PermisosModule;

class PermisosModulePolicy
{

    /**
     * Determine if the given user can view the permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function view(User $user, PermisosModule $permisos_module)
    {
        if ($user->canDo('church.permisos_module.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $permisos_module->user_id;
    }

    /**
     * Determine if the given user can create a permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('church.permisos_module.create');
    }

    /**
     * Determine if the given user can update the given permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function update(User $user, PermisosModule $permisos_module)
    {
        if ($user->canDo('church.permisos_module.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $permisos_module->user_id;
    }

    /**
     * Determine if the given user can delete the given permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function destroy(User $user, PermisosModule $permisos_module)
    {
        if ($user->canDo('church.permisos_module.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $permisos_module->user_id;
    }

    /**
     * Determine if the given user can verify the given permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function verify(User $user, PermisosModule $permisos_module)
    {
        if ($user->canDo('church.permisos_module.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('church.permisos_module.verify') 
        && $user->is('manager')
        && $permisos_module->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given permisos_module.
     *
     * @param User $user
     * @param PermisosModule $permisos_module
     *
     * @return bool
     */
    public function approve(User $user, PermisosModule $permisos_module)
    {
        if ($user->canDo('church.permisos_module.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
