<?php

namespace Church\Church\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Church\Church\Models\PermisosModule;

class PermisosModuleAction
{
    /**
     * Perform the complete action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */
    public function complete(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'complete';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */public function verify(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'verify';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */public function approve(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'approve';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */public function publish(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'publish';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */
    public function archive(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'archive';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param PermisosModule $permisos_module
     *
     * @return PermisosModule
     */
    public function unpublish(PermisosModule $permisos_module)
    {
        try {
            $permisos_module->status = 'unpublish';
            return $permisos_module->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
