<?php

namespace Church\Church\Workflow;

use Church\Church\Models\PermisosModule;
use Validator;

class PermisosModuleValidator
{

    /**
     * Determine if the given permisos_module is valid for complete status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function complete(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given permisos_module is valid for verify status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function verify(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given permisos_module is valid for approve status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function approve(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given permisos_module is valid for publish status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function publish(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given permisos_module is valid for archive status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function archive(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given permisos_module is valid for unpublish status.
     *
     * @param PermisosModule $permisos_module
     *
     * @return bool / Validator
     */
    public function unpublish(PermisosModule $permisos_module)
    {
        return Validator::make($permisos_module->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
